var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import React, { useState, useEffect, useRef } from 'react';
import styled from 'styled-components';
import { format } from 'date-fns';
import defaultTheme from "../../../theme";
import { Icon } from '../Icon';
import { Keys, TIME_FORMAT, TIME_RANGE_REGEXP } from './consts';
import { getDateFromTimeStr, getEndOfDay, getStartOfDay, isValidDateRange, } from './utils';
var TIME_FORMAT_ERROR = "Invalid time range format, please type time in format '" + TIME_FORMAT + "' - '" + TIME_FORMAT + "'";
var TIME_RANGE_ERROR = 'Invalid time range: start time should be less than end time';
export var TimeControl = function (_a) {
    var startDate = _a.startDate, endDate = _a.endDate, onChange = _a.onChange, onChangeRaw = _a.onChangeRaw, onClear = _a.onClear, _b = _a.predefinedTime, predefinedTime = _b === void 0 ? false : _b;
    var _c = useState(''), time = _c[0], setTime = _c[1];
    var _d = useState(''), error = _d[0], setError = _d[1];
    var timeRef = useRef(null);
    var validate = function (start, end) {
        if (isValidDateRange(start, end)) {
            setError('');
        }
        else {
            setError(TIME_RANGE_ERROR);
        }
    };
    useEffect(function () {
        var timeFormatError = error === TIME_FORMAT_ERROR;
        var skipInit = !predefinedTime && timeFormatError;
        if (skipInit) {
            return;
        }
        var timeStr = '';
        if (startDate) {
            var startTime = format(startDate, TIME_FORMAT);
            timeStr = startTime + " -";
            setError('');
            if (endDate) {
                var endTime = format(endDate, TIME_FORMAT);
                timeStr = startTime + " - " + endTime;
                validate(startDate, endDate);
            }
        }
        setTime(timeStr);
    }, [startDate, endDate, predefinedTime]);
    var handleBlur = function () {
        if (time) {
            var match = time.trim().match(TIME_RANGE_REGEXP);
            if (!match) {
                setError(TIME_FORMAT_ERROR);
                return;
            }
            var start = match[1];
            var end = match[6];
            var initialStartDate = getStartOfDay(startDate);
            var initialEndDate = getEndOfDay(endDate || initialStartDate);
            var startDateWithTime = getDateFromTimeStr(start, initialStartDate);
            var endDateWithTime = getDateFromTimeStr(end, initialEndDate);
            onChange({
                startDate: startDateWithTime,
                endDate: endDateWithTime,
            });
        }
        else {
            onClear();
        }
    };
    var handleChange = function (e) {
        var value = e.target.value;
        setTime(value);
        var valid = value ? TIME_RANGE_REGEXP.test(value.trim()) : true;
        if (valid) {
            setError('');
        }
        onChangeRaw(valid);
    };
    var handleKeyDown = function (e) {
        var code = e.code;
        if (!Object.values(Keys).includes(code)) {
            e.preventDefault();
        }
        if (code === Keys.ENTER || code === Keys.ESC) {
            (timeRef === null || timeRef === void 0 ? void 0 : timeRef.current) && timeRef.current.blur();
        }
    };
    return (React.createElement(TimeControlWrapper, null,
        React.createElement(Icon, { name: "clock", regular: true, size: "big", fitted: true }),
        React.createElement(TimeControlInput, { ref: timeRef, value: time, placeholder: "Type an exact time, e.g. 18:00 - 23:59", onChange: handleChange, onBlur: handleBlur, onKeyDown: handleKeyDown }),
        error && React.createElement(TimeControlError, null, error)));
};
var TimeControlInput = styled('input').withConfig({ displayName: "TimeControlInput", componentId: "sc-1q8whs1" })(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  border: none;\n  outline: none;\n  width: 256px;\n  color: inherit;\n  margin-left: 13px;\n  font-size: inherit;\n  font-family: inherit;\n  height: 21px;\n  padding: 0;\n\n  &::placeholder {\n    font-style: italic;\n  }\n"], ["\n  border: none;\n  outline: none;\n  width: 256px;\n  color: inherit;\n  margin-left: 13px;\n  font-size: inherit;\n  font-family: inherit;\n  height: 21px;\n  padding: 0;\n\n  &::placeholder {\n    font-style: italic;\n  }\n"])));
var TimeControlError = styled('span').withConfig({ displayName: "TimeControlError", componentId: "sc-khvra8" })(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  font-style: italic;\n  font-size: 12px;\n  position: absolute;\n  top: 100%;\n  left: 34px;\n\n  ", "\n"], ["\n  font-style: italic;\n  font-size: 12px;\n  position: absolute;\n  top: 100%;\n  left: 34px;\n\n  ",
    "\n"])), function (_a) {
    var theme = _a.theme;
    return ({
        color: theme.colors.red.default,
    });
});
TimeControlError.defaultProps = {
    theme: defaultTheme,
};
var TimeControlWrapper = styled('div').withConfig({ displayName: "TimeControlWrapper", componentId: "sc-13h563n" })(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  position: relative;\n  margin-bottom: 20px;\n  width: 100%;\n"], ["\n  display: flex;\n  align-items: center;\n  position: relative;\n  margin-bottom: 20px;\n  width: 100%;\n"])));
var templateObject_1, templateObject_2, templateObject_3;
