import { CSSObject } from 'styled-components';
import { ReactNode } from 'react';
import { IconName } from '@fortawesome/fontawesome-svg-core';
declare type ExtraPartial<T> = {
    [P in keyof T]?: T[P] extends Record<infer K, infer U> ? Partial<T[P]> : T[P];
};
export interface PlainObject {
    [index: string]: any;
}
export declare type HiroColors = 'primary' | 'secondary' | 'primaryText' | 'secondaryText' | 'red' | 'orange' | 'yellow' | 'green' | 'teal' | 'blue' | 'purple' | 'pink' | 'brown' | 'black' | 'grey' | 'white';
export declare type Greyscales = 'lightest' | 'lighter' | 'light' | 'medium' | 'dark' | 'darker' | 'darkest';
export declare type FixedWidth = string | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16;
export interface BreakpointDefinitions {
    sm: number;
    md: number;
    lg: number;
    xl: number;
}
export declare type ColorDefinitionValuesEnum = 'default' | 'active' | 'hover' | 'light' | 'dark' | 'verylight' | 'highlighted' | 'highlightedHover' | 'saturated' | 'disabled' | 'transparent' | 'verytransparent' | 'blured';
export declare type ColorDefinitionValues = Record<ColorDefinitionValuesEnum, string>;
export declare type SizeScale = 'mini' | 'tiny' | 'small' | 'medium' | 'large' | 'big' | 'huge' | 'massive';
export declare type ColorDefinitions = Record<HiroColors, ColorDefinitionValues>;
export declare type ColorOverwrite = {
    [C in ColorDefinitionValuesEnum]?: string;
} & {
    default: string;
};
export interface FontDefinitons {
    h1: CSSObject;
    h2: CSSObject;
    h3: CSSObject;
}
export declare type GreyscaleDefinitions = {
    [K in Greyscales]: string;
};
export interface SizeDefinitions {
    borderRadius: string | number;
    borderRadiusInput: string | number;
    padding: Record<'normal' | 'extra', string>;
    scale: Record<SizeScale, number>;
    width: BreakpointDefinitions;
}
export interface HiroDefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: Record<HiroColors, string | ColorOverwrite>;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
    name: string;
}
export interface HiroPartialTheme {
    name?: string;
    breakpoints?: ExtraPartial<BreakpointDefinitions>;
    colors?: ExtraPartial<Record<HiroColors, string | ColorOverwrite>>;
    font?: ExtraPartial<FontDefinitons>;
    global?: CSSObject;
    greyscale?: ExtraPartial<GreyscaleDefinitions>;
    sizes?: ExtraPartial<SizeDefinitions>;
    gradients?: ExtraPartial<Record<HiroColors, string | ColorOverwrite>>;
}
export interface DefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: ColorDefinitions;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
    gradients?: ColorDefinitions;
}
declare module 'styled-components' {
    interface DefaultTheme {
        breakpoints: BreakpointDefinitions;
        colors: ColorDefinitions;
        font: FontDefinitons;
        global: CSSObject;
        greyscale: GreyscaleDefinitions;
        sizes: SizeDefinitions;
        gradients?: ColorDefinitions;
    }
}
export declare type HiroIcons = IconName;
export declare type renderType = () => ReactNode;
export interface VariablesProps {
    [key: string]: string[];
}
export interface Rules {
    start: Rule[];
}
export interface Rule {
    regex: string | null;
    token: string;
}
export interface OriginNodeData {
    name: string;
    url: string;
}
export interface UserFromOgit {
    id: string;
    name: string;
    status?: string;
    email: string;
    roles?: string;
    avatar: string;
}
export interface SessionData {
    id: string;
    title: string;
    description?: string | null;
    archived: boolean;
    knowledgeOwner?: string;
    originNodeHref?: OriginNodeData | null;
    actions?: ReactNode[];
    descriptionActions?: ReactNode[];
    commentsCount?: number;
    handedOver?: boolean;
    conversionReviewerIds?: string[];
    teachingReviewerIds?: string[];
    teachingReviewParticipantIds?: string[];
    conversionReviewParticipantIds?: string[];
    conversionOwnerId?: string;
    teachingOwnerId?: string;
    teachingRoomsCompleted?: number;
    teachingRooms?: number;
    teachingStepsDeployed?: number;
    teachingSteps?: number;
    auditReviewMode: boolean;
    approvedTeams?: Team[];
    rejectedTeams?: Team[];
}
export interface Reviewer extends UserFromOgit {
    reviewDone: boolean;
}
export interface ViewData {
    action: () => void;
    title: string;
}
export interface Team {
    id: string;
    name: string;
    description: string;
}
export {};
