import { useRef, useEffect } from 'react';
export var useOnClickOutside = function (onClickOutside) {
    var ref = useRef(null);
    useEffect(function () {
        var listener = function (event) {
            // Do nothing if clicking ref's element or descendent elements
            var target = event.target;
            if (!ref.current || ref.current.contains(target)) {
                return;
            }
            onClickOutside(event);
        };
        document.addEventListener('mousedown', listener);
        document.addEventListener('touchstart', listener);
        return function () {
            document.removeEventListener('mousedown', listener);
            document.removeEventListener('touchstart', listener);
        };
    }, [onClickOutside, ref]);
    return ref;
};
